@@ -2,7 +2,7 @@ from typing import Union, Type
 from sqlalchemy.orm import DeclarativeMeta
 from sqlalchemy.orm.util import AliasedClass
 from sqlalchemy.sql import Select, Insert, Update, Delete
-from ..query.join_query import JoinQuery
+from ..query import CRUDQuery
 from .base import BaseProvider
 
 
@@ -10,7 +10,7 @@ class JoinProvider(BaseProvider):
     def _join(
         self,
         field_name: str,
-        query: Union[JoinQuery, Type[JoinQuery]],
+        query: Union[CRUDQuery, Type[CRUDQuery]],
         stmt: Union[Select, Insert, Update, Delete],
         mapper: DeclarativeMeta,
         aliased_mapper: AliasedClass
@@ -18,9 +18,11 @@ class JoinProvider(BaseProvider):
         mapper_field = getattr(mapper, field_name)
         join_strategy = query.get_join_strategy(field_name=field_name)
 
-        return stmt.join(
+        stmt2 = stmt.join(
             aliased_mapper,
             onclause=mapper_field,
             isouter=join_strategy.is_outer,
             full=join_strategy.is_full
         )
+
+        return stmt2
