@@ -1,12 +1,12 @@
 from .base import BaseQuery
-from .from_row import FromRowQuery
+from .from_query import FromQuery
 from .join_query import JoinQuery
 from .pagination_query import PaginationQuery
 from .sorting_query import SortingQuery
 
 
 class SelectQuery(
-    FromRowQuery,
+    FromQuery,
     JoinQuery,
     PaginationQuery,
     SortingQuery,
